@@ -1,12 +1,11 @@
 package Web::Machine;
-BEGIN {
-  $Web::Machine::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A Perl port of Webmachine
-$Web::Machine::VERSION = '0.15';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.16';
+
 use Try::Tiny;
 use Carp         qw[ confess ];
 use Scalar::Util qw[ blessed ];
@@ -66,7 +65,7 @@ sub finalize_response {
 sub call {
     my ($self, $env) = @_;
 
-    my $request  = try { $self->inflate_request( $env ) };
+    my $request = try { $self->inflate_request($env) };
 
     return $self->finalize_response( Plack::Response->new( 400 ) )
         unless defined $request;
@@ -115,7 +114,7 @@ Web::Machine - A Perl port of Webmachine
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -174,12 +173,8 @@ thrown in for good measure.
 You can learn a bit about Web::Machine's history from the slides for my L<2012
 YAPC::NA talk|https://speakerdeck.com/stevan_little/rest-from-the-trenches>.
 
-=head1 CAVEAT
-
-This module is extremely young and it is a port of an pretty young (June 2011)
-module in another language (ruby), which itself is a port of a still kind of
-young module (March 2009) in yet another language (Erlang). But that all said,
-it really seems like a sane idea and so I stole it and ported it to Perl.
+To learn more about Webmachine, take a look at the links in the SEE ALSO
+section.
 
 =head1 METHODS
 
@@ -241,10 +236,15 @@ This is the C<call> method overridden from the L<Plack::Component> superclass.
 If you set the C<WM_DEBUG> environment variable to C<1> we will print
 out information about the path taken through the state machine to STDERR.
 
+If you set C<WM_DEBUG> to C<diag> then debugging information will be printed
+using L<Test::More>'s C<diag()> sub instead.
+
 =head1 SEE ALSO
 
 =over 4
 
+=item The diagram - L<https://github.com/Webmachine/webmachine/wiki/Diagram>
+
 =item Original Erlang - L<https://github.com/basho/webmachine>
 
 =item Ruby port - L<https://github.com/seancribbs/webmachine-ruby>
@@ -255,14 +255,30 @@ out information about the path taken through the state machine to STDERR.
 
 =item 2012 YAPC::NA slides - L<https://speakerdeck.com/stevan_little/rest-from-the-trenches>
 
+=item an elaborate machine is indispensable: a blog post by Justin Sheehy - L<http://blog.therestfulway.com/2008/09/webmachine-is-resource-server-for-web.html>
+
+=item Resources, For Real This Time (with Webmachine): a video by Sean Cribbs - L<http://www.youtube.com/watch?v=odRrLK87s_Y>
+
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Stevan Little <stevan.little@iinteractive.com>
+=over 4
+
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
 
 =head1 CONTRIBUTORS
 
+=for stopwords Andreas Marienborg Andrew Nelson Arthur Axel 'fREW' Schmidt Carlos Fernando Avila Gratz Fayland Lam George Hartzell Gregory Oschwald Jesse Luehrs John SJ Anderson Mike Raynham Nathan Cutler Olaf Alders Thomas Sibley
+
 =over 4
 
 =item *
@@ -283,10 +299,6 @@ Carlos Fernando Avila Gratz <cafe@q1software.com>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
 Fayland Lam <fayland@gmail.com>
 
 =item *
@@ -315,6 +327,10 @@ Mike Raynham <mike.raynham@spareroom.co.uk>
 
 =item *
 
+Nathan Cutler <ncutler@suse.cz>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -325,7 +341,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc..
+This software is copyright (c) 2015 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
