@@ -1,12 +1,11 @@
 package Web::Machine::FSM;
-BEGIN {
-  $Web::Machine::FSM::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: The State Machine runner
-$Web::Machine::FSM::VERSION = '0.15';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.16';
+
 use IO::Handle::Util 'io_from_getline';
 use Plack::Util;
 use Try::Tiny;
@@ -34,7 +33,13 @@ sub tracing_header { (shift)->{'tracing_header'} }
 sub run {
     my ( $self, $resource ) = @_;
 
-    my $DEBUG = $ENV{'WM_DEBUG'};
+    my $DEBUG;
+    if ( $ENV{WM_DEBUG} ) {
+        $DEBUG
+            = $ENV{WM_DEBUG} eq 'diag'
+            ? sub { Test::More::diag( $_[0] ) }
+            : sub { warn "$_[0]\n" };
+    }
 
     my $request  = $resource->request;
     my $response = $resource->response;
@@ -48,7 +53,11 @@ sub run {
 
     try {
         while (1) {
-            warn "entering " . get_state_name( $state ) . " (" . get_state_desc( $state ) . ")\n" if $DEBUG;
+            $DEBUG->( 'entering '
+                    . get_state_name($state) . ' ('
+                    . get_state_desc($state)
+                    . ')' )
+                if $DEBUG;
             push @trace => get_state_name( $state ) if $tracing;
             my $result = $state->( $resource, $request, $response, $metadata );
             if ( ! ref $result ) {
@@ -56,14 +65,15 @@ sub run {
                 # We should be I18N this
                 # specific error
                 # - SL
-                warn "! ERROR with " . ($result || 'undef') . "\n" if $DEBUG;
+                $DEBUG->( '! ERROR with ' . ( $result || 'undef' ) )
+                    if $DEBUG;
                 $response->status( 500 );
                 $response->header( 'Content-Type' => 'text/plain' );
                 $response->body( [ "Got bad state: " . ($result || 'undef') ] );
                 last;
             }
             elsif ( is_status_code( $result ) ) {
-                warn ".. terminating with " . ${ $result } . "\n" if $DEBUG;
+                $DEBUG->( '.. terminating with ' . ${$result} ) if $DEBUG;
                 $response->status( $$result );
 
                 if ( is_error( $$result ) && !$response->body ) {
@@ -78,17 +88,23 @@ sub run {
                     $response->body([ $lang->maketext( $$result ) ]);
                 }
 
-                if ( $DEBUG ) {
+                if ($DEBUG) {
                     require Data::Dumper;
-                    local $Data::Dumper::Useqq = 1;
-                    warn Data::Dumper::Dumper( $request->env );
-                    warn Data::Dumper::Dumper( $response->finalize );
+                    local $Data::Dumper::Terse     = 1;
+                    local $Data::Dumper::Indent    = 1;
+                    local $Data::Dumper::Useqq     = 1;
+                    local $Data::Dumper::Deparse   = 1;
+                    local $Data::Dumper::Quotekeys = 0;
+                    local $Data::Dumper::Sortkeys  = 1;
+                    $DEBUG->( Data::Dumper::Dumper( $request->env ) );
+                    $DEBUG->( Data::Dumper::Dumper( $response->finalize ) );
                 }
 
                 last;
             }
             elsif ( is_new_state( $result ) ) {
-                warn "-> transitioning to " . get_state_name( $result ) . "\n" if $DEBUG;
+                $DEBUG->( '-> transitioning to ' . get_state_name($result) )
+                    if $DEBUG;
                 $state = $result;
             }
         }
@@ -96,7 +112,7 @@ sub run {
         # TODO:
         # We should be I18N the errors
         # - SL
-        warn $_ if $DEBUG;
+        $DEBUG->($_) if $DEBUG;
 
         if ( $request->logger ) {
             $request->logger->( { level => 'error', message => $_ } );
@@ -118,7 +134,7 @@ sub run {
         $resource->finish_request( $metadata );
     }
     catch {
-        warn $_ if $DEBUG;
+        $DEBUG->($_) if $DEBUG;
 
         if ( $request->logger ) {
             $request->logger->( { level => 'error', message => $_ } );
@@ -174,7 +190,7 @@ Web::Machine::FSM - The State Machine runner
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -186,6 +202,8 @@ This is the heart of the L<Web::Machine>, this is the thing
 which runs the state machine whose states are contained in the
 L<Web::Machine::FSM::States> module.
 
+=for Pod::Coverage filter_response
+
 =head1 METHODS
 
 =over 4
@@ -217,16 +235,28 @@ the state machine.
 
 =over 4
 
-=item L<Web Machine state diagram|http://wiki.basho.com/Webmachine-Diagram.html>
+=item L<Web Machine state diagram|https://github.com/Webmachine/webmachine/wiki/Diagram>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Stevan Little <stevan.little@iinteractive.com>
+=over 4
+
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
 
 =head1 CONTRIBUTORS
 
+=for stopwords Andreas Marienborg Andrew Nelson Arthur Axel 'fREW' Schmidt Carlos Fernando Avila Gratz Fayland Lam George Hartzell Gregory Oschwald Jesse Luehrs John SJ Anderson Mike Raynham Nathan Cutler Olaf Alders Thomas Sibley
+
 =over 4
 
 =item *
@@ -247,10 +277,6 @@ Carlos Fernando Avila Gratz <cafe@q1software.com>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
 Fayland Lam <fayland@gmail.com>
 
 =item *
@@ -279,6 +305,10 @@ Mike Raynham <mike.raynham@spareroom.co.uk>
 
 =item *
 
+Nathan Cutler <ncutler@suse.cz>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -289,7 +319,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc..
+This software is copyright (c) 2015 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
