@@ -1,12 +1,11 @@
 package Web::Machine::FSM::States;
-BEGIN {
-  $Web::Machine::FSM::States::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: The States for Web Machine
-$Web::Machine::FSM::States::VERSION = '0.15';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.16';
+
 use B ();
 use Hash::MultiValue;
 
@@ -143,8 +142,9 @@ $STATE_DESC{'b10'} = 'method_allowed';
 sub b10 {
     my ($resource, $request, $response) = @_;
     my $method = $request->method;
-    return \&b9 if grep { $method eq $_ } @{ $resource->allowed_methods };
-    $response->header('Allow' => join ", " => @{ $resource->allowed_methods } );
+    my @allowed_methods = @{ $resource->allowed_methods };
+    return \&b9 if grep { $method eq $_ } @allowed_methods;
+    $response->header('Allow' => join ", " => @allowed_methods );
     return \405;
 }
 
@@ -208,7 +208,7 @@ sub b6 {
 $STATE_DESC{'b5'} = 'known_content_type';
 sub b5 {
     my ($resource, $request, $response) = @_;
-    $resource->known_content_type( $request->content_type ) ? \&b4 : \415;
+    $resource->known_content_type( $request->header('Content-Type') ) ? \&b4 : \415;
 }
 
 $STATE_DESC{'b4'} = 'request_entity_too_large';
@@ -744,7 +744,7 @@ Web::Machine::FSM::States - The States for Web Machine
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -761,16 +761,28 @@ try and document this, but for now the task is simply too daunting.
 
 =over 4
 
-=item L<Web Machine state diagram|http://wiki.basho.com/Webmachine-Diagram.html>
+=item L<Web Machine state diagram|https://github.com/Webmachine/webmachine/wiki/Diagram>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Stevan Little <stevan.little@iinteractive.com>
+=over 4
+
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
 
 =head1 CONTRIBUTORS
 
+=for stopwords Andreas Marienborg Andrew Nelson Arthur Axel 'fREW' Schmidt Carlos Fernando Avila Gratz Fayland Lam George Hartzell Gregory Oschwald Jesse Luehrs John SJ Anderson Mike Raynham Nathan Cutler Olaf Alders Thomas Sibley
+
 =over 4
 
 =item *
@@ -791,10 +803,6 @@ Carlos Fernando Avila Gratz <cafe@q1software.com>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
 Fayland Lam <fayland@gmail.com>
 
 =item *
@@ -823,6 +831,10 @@ Mike Raynham <mike.raynham@spareroom.co.uk>
 
 =item *
 
+Nathan Cutler <ncutler@suse.cz>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -833,7 +845,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc..
+This software is copyright (c) 2015 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
