@@ -1,14 +1,13 @@
 package Web::Machine::I18N::en;
-BEGIN {
-  $Web::Machine::I18N::en::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: The English support for I18N-ed HTTP information
-$Web::Machine::I18N::en::VERSION = '0.15';
+
 use strict;
 use warnings;
 
 use parent 'Web::Machine::I18N';
 
+our $VERSION = '0.16';
+
 our %Lexicon = (
     100 => 'Continue',
     101 => 'Switching Protocols',
@@ -65,7 +64,7 @@ Web::Machine::I18N::en - The English support for I18N-ed HTTP information
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -77,12 +76,24 @@ version 0.15
 
 L<Web::Machine::I18N>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Stevan Little <stevan.little@iinteractive.com>
+=over 4
+
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
 
 =head1 CONTRIBUTORS
 
+=for stopwords Andreas Marienborg Andrew Nelson Arthur Axel 'fREW' Schmidt Carlos Fernando Avila Gratz Fayland Lam George Hartzell Gregory Oschwald Jesse Luehrs John SJ Anderson Mike Raynham Nathan Cutler Olaf Alders Thomas Sibley
+
 =over 4
 
 =item *
@@ -103,10 +114,6 @@ Carlos Fernando Avila Gratz <cafe@q1software.com>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
 Fayland Lam <fayland@gmail.com>
 
 =item *
@@ -135,6 +142,10 @@ Mike Raynham <mike.raynham@spareroom.co.uk>
 
 =item *
 
+Nathan Cutler <ncutler@suse.cz>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -145,7 +156,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc..
+This software is copyright (c) 2015 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
