@@ -1,12 +1,11 @@
 package Web::Machine::Resource;
-BEGIN {
-  $Web::Machine::Resource::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A base resource class
-$Web::Machine::Resource::VERSION = '0.15';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.16';
+
 use Carp         qw[ confess ];
 use Scalar::Util qw[ blessed ];
 
@@ -87,7 +86,7 @@ Web::Machine::Resource - A base resource class
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -116,7 +115,7 @@ This is the core representation of the web resource in
 L<Web::Machine>. It is this object which is interrogated
 through the state machine. It is important not to think
 of this as an instance of a single object, but as a web
-representation of a resource, there is a big difference.
+representation of a resource: there is a big difference.
 
 For now I am keeping the documentation short, but much more needs to be
 written here. Below you will find a description of each method this object
@@ -129,8 +128,13 @@ not be able to return any useful content.
 The documentation was lovingly stolen from the ruby port
 of webmachine.
 
+=for Pod::Coverage new
+
 =head1 METHODS
 
+Keep in mind that the methods may be called more than once
+per request, so your implementations should be idempotent.
+
 =over 4
 
 =item C<init( \%args )>
@@ -293,7 +297,7 @@ If the request includes any invalid Content-* headers, this
 should return false, which will result in a '501 Not
 Implemented' response.
 
-Defaults to false.
+Defaults to true.
 
 =item C<valid_entity_length( $length )>
 
@@ -576,12 +580,24 @@ must be by modifying the response.
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Stevan Little <stevan.little@iinteractive.com>
+=over 4
+
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
 
 =head1 CONTRIBUTORS
 
+=for stopwords Andreas Marienborg Andrew Nelson Arthur Axel 'fREW' Schmidt Carlos Fernando Avila Gratz Fayland Lam George Hartzell Gregory Oschwald Jesse Luehrs John SJ Anderson Mike Raynham Nathan Cutler Olaf Alders Thomas Sibley
+
 =over 4
 
 =item *
@@ -602,10 +618,6 @@ Carlos Fernando Avila Gratz <cafe@q1software.com>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
 Fayland Lam <fayland@gmail.com>
 
 =item *
@@ -634,6 +646,10 @@ Mike Raynham <mike.raynham@spareroom.co.uk>
 
 =item *
 
+Nathan Cutler <ncutler@suse.cz>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -644,7 +660,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc..
+This software is copyright (c) 2015 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
