@@ -1,12 +1,11 @@
 package Web::Machine::Util;
-BEGIN {
-  $Web::Machine::Util::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: General Utility module
-$Web::Machine::Util::VERSION = '0.15';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.16';
+
 use Carp         qw[ confess ];
 use Scalar::Util qw[ blessed ];
 use List::Util   qw[ first ];
@@ -84,7 +83,7 @@ Web::Machine::Util - General Utility module
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -96,6 +95,8 @@ This is just a basic utility module used internally by
 L<Web::Machine>. There are no real user serviceable parts
 in here.
 
+=for Pod::Coverage get_action_pack
+
 =head1 FUNCTIONS
 
 =over 4
@@ -117,7 +118,7 @@ We represent a pair simply as a HASH ref with one key.
 
 This will call C<inflate> on an instance of L<HTTP::Headers::ActionPack>.
 
-=item C<create_headers( @args )>
+=item C<create_header( @args )>
 
 This will call C<create> on an instance of L<HTTP::Headers::ActionPack>.
 
@@ -184,12 +185,24 @@ an array with zero size).
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Stevan Little <stevan.little@iinteractive.com>
+=over 4
+
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
 
 =head1 CONTRIBUTORS
 
+=for stopwords Andreas Marienborg Andrew Nelson Arthur Axel 'fREW' Schmidt Carlos Fernando Avila Gratz Fayland Lam George Hartzell Gregory Oschwald Jesse Luehrs John SJ Anderson Mike Raynham Nathan Cutler Olaf Alders Thomas Sibley
+
 =over 4
 
 =item *
@@ -210,10 +223,6 @@ Carlos Fernando Avila Gratz <cafe@q1software.com>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
 Fayland Lam <fayland@gmail.com>
 
 =item *
@@ -242,6 +251,10 @@ Mike Raynham <mike.raynham@spareroom.co.uk>
 
 =item *
 
+Nathan Cutler <ncutler@suse.cz>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -252,7 +265,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc..
+This software is copyright (c) 2015 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
