@@ -1,12 +1,11 @@
 package Web::Machine::Util::BodyEncoding;
-BEGIN {
-  $Web::Machine::Util::BodyEncoding::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: Module to handle body encoding
-$Web::Machine::Util::BodyEncoding::VERSION = '0.15';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.16';
+
 use Scalar::Util qw/ weaken isweak /;
 use Encode ();
 use Web::Machine::Util qw[ first pair_key pair_value ];
@@ -69,7 +68,7 @@ Web::Machine::Util::BodyEncoding - Module to handle body encoding
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -101,12 +100,24 @@ body is returned as a CODE ref. This is a bug to be remedied in the future.
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Stevan Little <stevan.little@iinteractive.com>
+=over 4
+
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
 
 =head1 CONTRIBUTORS
 
+=for stopwords Andreas Marienborg Andrew Nelson Arthur Axel 'fREW' Schmidt Carlos Fernando Avila Gratz Fayland Lam George Hartzell Gregory Oschwald Jesse Luehrs John SJ Anderson Mike Raynham Nathan Cutler Olaf Alders Thomas Sibley
+
 =over 4
 
 =item *
@@ -127,10 +138,6 @@ Carlos Fernando Avila Gratz <cafe@q1software.com>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
 Fayland Lam <fayland@gmail.com>
 
 =item *
@@ -159,6 +166,10 @@ Mike Raynham <mike.raynham@spareroom.co.uk>
 
 =item *
 
+Nathan Cutler <ncutler@suse.cz>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -169,7 +180,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc..
+This software is copyright (c) 2015 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
