@@ -1,12 +1,11 @@
 package Web::Machine::Util::ContentNegotiation;
-BEGIN {
-  $Web::Machine::Util::ContentNegotiation::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: Module to handle content negotiation
-$Web::Machine::Util::ContentNegotiation::VERSION = '0.15';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.16';
+
 use Scalar::Util qw[ blessed ];
 
 use Web::Machine::Util qw[
@@ -70,11 +69,11 @@ Web::Machine::Util::ContentNegotiation - Module to handle content negotiation
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
-  use Web::Machine::FSM::ContentNegotiation;
+  use Web::Machine::Util::ContentNegotiation;
 
 =head1 DESCRIPTION
 
@@ -111,12 +110,24 @@ to negotiate the best encoding match.
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Stevan Little <stevan.little@iinteractive.com>
+=over 4
+
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
 
 =head1 CONTRIBUTORS
 
+=for stopwords Andreas Marienborg Andrew Nelson Arthur Axel 'fREW' Schmidt Carlos Fernando Avila Gratz Fayland Lam George Hartzell Gregory Oschwald Jesse Luehrs John SJ Anderson Mike Raynham Nathan Cutler Olaf Alders Thomas Sibley
+
 =over 4
 
 =item *
@@ -137,10 +148,6 @@ Carlos Fernando Avila Gratz <cafe@q1software.com>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
 Fayland Lam <fayland@gmail.com>
 
 =item *
@@ -169,6 +176,10 @@ Mike Raynham <mike.raynham@spareroom.co.uk>
 
 =item *
 
+Nathan Cutler <ncutler@suse.cz>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -179,7 +190,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc..
+This software is copyright (c) 2015 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
