@@ -6,6 +6,6 @@ use parent 'Web::Machine::Resource';
 
 sub content_types_provided { [ { 'text/plain' => sub {} } ] }
 sub languages_provided     { [qw[ de fr ]] }
-sub charsets_provided      { [ { 'utf-8' => sub {} } ] }
+sub charsets_provided      { [ { 'ISO-8859-2' => sub {} } ] }
 
-1;
\ No newline at end of file
+1;
